@@ -37,6 +37,7 @@ struct _EntangleCameraListPrivate {
     size_t ncamera;
     EntangleCamera **cameras;
 
+    gboolean active;
     EntangleDeviceManager *devManager;
 
     GPContext *ctx;
@@ -49,9 +50,22 @@ G_DEFINE_TYPE(EntangleCameraList, entangle_camera_list, G_TYPE_OBJECT);
 enum {
     PROP_0,
     PROP_DEVMANAGER,
+    PROP_ACTIVE,
 };
 
 
+static void entangle_camera_list_udev_event(EntangleDeviceManager *manager G_GNUC_UNUSED,
+                                            char *port G_GNUC_UNUSED,
+                                            gpointer opaque)
+{
+    EntangleCameraList *list = ENTANGLE_CAMERA_LIST(opaque);
+
+    if (!entangle_camera_list_refresh(list, NULL)) {
+        ENTANGLE_DEBUG("Failed to refresh cameras after device hotplug/unplug");
+    }
+}
+
+
 static void entangle_camera_list_get_property(GObject *object,
                                               guint prop_id,
                                               GValue *value,
@@ -65,6 +79,10 @@ static void entangle_camera_list_get_property(GObject *object,
         g_value_set_object(value, priv->devManager);
         break;
 
+    case PROP_ACTIVE:
+        g_value_set_boolean(value, priv->active);
+        break;
+
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
     }
@@ -86,6 +104,11 @@ static void entangle_camera_list_set_property(GObject *object,
         g_object_ref(priv->devManager);
         break;
 
+    case PROP_ACTIVE:
+        priv->active = g_value_get_boolean(value);
+        entangle_camera_list_refresh(list, NULL);
+        break;
+
     default:
         G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
     }
@@ -117,18 +140,6 @@ static void entangle_camera_list_finalize(GObject *object)
 }
 
 
-static void entangle_camera_list_udev_event(EntangleDeviceManager *manager G_GNUC_UNUSED,
-                                            char *port G_GNUC_UNUSED,
-                                            gpointer opaque)
-{
-    EntangleCameraList *list = ENTANGLE_CAMERA_LIST(opaque);
-
-    if (!entangle_camera_list_refresh(list, NULL)) {
-        ENTANGLE_DEBUG("Failed to refresh cameras after device hotplug/unplug");
-    }
-}
-
-
 #ifdef HAVE_GPHOTO25
 static void entangle_camera_list_gphoto_log(GPLogLevel level G_GNUC_UNUSED,
                                             const char *domain,
@@ -189,13 +200,52 @@ static void entangle_camera_list_class_init(EntangleCameraListClass *klass)
                                                         G_PARAM_STATIC_NICK |
                                                         G_PARAM_STATIC_BLURB));
 
+    g_object_class_install_property(object_class,
+                                    PROP_ACTIVE,
+                                    g_param_spec_boolean("active",
+                                                         "Active",
+                                                         "Track kactive cameras",
+                                                         FALSE,
+                                                         G_PARAM_READABLE |
+                                                         G_PARAM_WRITABLE |
+                                                         G_PARAM_CONSTRUCT_ONLY |
+                                                         G_PARAM_STATIC_NAME |
+                                                         G_PARAM_STATIC_NICK |
+                                                         G_PARAM_STATIC_BLURB));
+
     g_type_class_add_private(klass, sizeof(EntangleCameraListPrivate));
 }
 
 
-EntangleCameraList *entangle_camera_list_new(void)
+/**
+ * entangle_camera_list_new_active:
+ *
+ * Create a new camera list for enumerating camera
+ * cameras that are connected to the host computer
+ *
+ * Returns: (transfer full): the new camera list
+ */
+EntangleCameraList *entangle_camera_list_new_active(void)
 {
-    return ENTANGLE_CAMERA_LIST(g_object_new(ENTANGLE_TYPE_CAMERA_LIST, NULL));
+    return ENTANGLE_CAMERA_LIST(g_object_new(ENTANGLE_TYPE_CAMERA_LIST,
+                                             "active", TRUE,
+                                             NULL));
+}
+
+
+/**
+ * entangle_camera_list_new_supported:
+ *
+ * Create a new camera list for enumerating camera
+ * models that are supported by the library.
+ *
+ * Returns: (transfer full): the new camera list
+ */
+EntangleCameraList* entangle_camera_list_new_supported(void)
+{
+    return ENTANGLE_CAMERA_LIST(g_object_new(ENTANGLE_TYPE_CAMERA_LIST,
+                                             "active", FALSE,
+                                             NULL));
 }
 
 
@@ -212,30 +262,17 @@ static void entangle_camera_list_init(EntangleCameraList *list)
 
     priv->ctx = gp_context_new();
 
-    priv->devManager = entangle_device_manager_new();
-
     if (gp_abilities_list_new(&priv->caps) != GP_OK)
         g_error(_("Cannot initialize gphoto2 abilities"));
 
     if (gp_abilities_list_load(priv->caps, priv->ctx) != GP_OK)
         g_error(_("Cannot load gphoto2 abilities"));
-
-    if (gp_port_info_list_new(&priv->ports) != GP_OK)
-        g_error(_("Cannot initialize gphoto2 ports"));
-
-    if (gp_port_info_list_load(priv->ports) != GP_OK)
-        g_error(_("Cannot load gphoto2 ports"));
-
-    g_signal_connect(priv->devManager, "device-added",
-                     G_CALLBACK(entangle_camera_list_udev_event), list);
-    g_signal_connect(priv->devManager, "device-removed",
-                     G_CALLBACK(entangle_camera_list_udev_event), list);
-
-    entangle_camera_list_refresh(list, NULL);
 }
 
-gboolean entangle_camera_list_refresh(EntangleCameraList *list,
-                                      GError **error G_GNUC_UNUSED)
+
+static gboolean
+entangle_camera_list_refresh_active(EntangleCameraList *list,
+                                    GError **error G_GNUC_UNUSED)
 {
     g_return_val_if_fail(ENTANGLE_IS_CAMERA_LIST(list), FALSE);
 
@@ -326,6 +363,81 @@ gboolean entangle_camera_list_refresh(EntangleCameraList *list,
 }
 
 
+static gboolean
+entangle_camera_list_refresh_supported(EntangleCameraList *list,
+                                       GError **error G_GNUC_UNUSED)
+{
+    g_return_val_if_fail(ENTANGLE_IS_CAMERA_LIST(list), FALSE);
+
+    EntangleCameraListPrivate *priv = list->priv;
+    int cnt;
+    gsize i;
+
+    cnt = gp_abilities_list_count(priv->caps);
+
+    for (i = 0; i < cnt; i++) {
+        CameraAbilities cap;
+        EntangleCamera *cam;
+
+        gp_abilities_list_get_abilities(priv->caps, i, &cap);
+
+        cam = entangle_camera_new(cap.model, NULL,
+                                  cap.operations & GP_OPERATION_CAPTURE_IMAGE ? TRUE : FALSE,
+                                  cap.operations & GP_OPERATION_CAPTURE_PREVIEW ? TRUE : FALSE,
+                                  cap.operations & GP_OPERATION_CONFIG ? TRUE : FALSE);
+        entangle_camera_list_add(list, cam);
+        g_object_unref(cam);
+    }
+
+    return TRUE;
+}
+
+
+/**
+ * entangle_camera_list_refresh:
+ * @list: (transfer none): the camera list
+ *
+ * De-intialization the list of cameras
+ *
+ * Returns: TRUE if the refresh was successful, FALSE on error
+ */
+gboolean entangle_camera_list_refresh(EntangleCameraList *list,
+                                      GError **error)
+{
+    g_return_val_if_fail(ENTANGLE_IS_CAMERA_LIST(list), FALSE);
+
+    EntangleCameraListPrivate *priv = list->priv;
+
+    if (!priv->devManager && priv->active) {
+        priv->devManager = entangle_device_manager_new();
+
+        if (gp_port_info_list_new(&priv->ports) != GP_OK)
+            g_error(_("Cannot initialize gphoto2 ports"));
+
+        if (gp_port_info_list_load(priv->ports) != GP_OK)
+            g_error(_("Cannot load gphoto2 ports"));
+
+        g_signal_connect(priv->devManager, "device-added",
+                         G_CALLBACK(entangle_camera_list_udev_event), list);
+        g_signal_connect(priv->devManager, "device-removed",
+                         G_CALLBACK(entangle_camera_list_udev_event), list);
+    }
+
+    if (priv->active)
+        return entangle_camera_list_refresh_active(list, error);
+    else
+        return entangle_camera_list_refresh_supported(list, error);
+}
+
+
+/**
+ * entangle_camera_list_count:
+ * @list: (transfer none): the camera list
+ *
+ * Get the total number of cameras currently detected
+ *
+ * Returns: the number of cameras
+ */
 int entangle_camera_list_count(EntangleCameraList *list)
 {
     g_return_val_if_fail(ENTANGLE_IS_CAMERA_LIST(list), 0);
@@ -335,6 +447,14 @@ int entangle_camera_list_count(EntangleCameraList *list)
     return priv->ncamera;
 }
 
+
+/**
+ * entangle_camera_list_add:
+ * @list: (transfer none): the camera list
+ * @cam: (transfer none): the camera to add
+ *
+ * Adds the camera @cam to the list @list
+ */
 void entangle_camera_list_add(EntangleCameraList *list,
                               EntangleCamera *cam)
 {
@@ -348,9 +468,18 @@ void entangle_camera_list_add(EntangleCameraList *list,
     g_object_ref(cam);
 
     g_signal_emit_by_name(list, "camera-added", cam);
-    ENTANGLE_DEBUG("Added camera %p", cam);
+    ENTANGLE_DEBUG("Added camera %p %s %s", cam, entangle_camera_get_model(cam),
+                   entangle_camera_get_port(cam));
 }
 
+
+/**
+ * entangle_camera_list_remove:
+ * @list: (transfer none): the camera list
+ * @cam: (transfer none): the camera to remove
+ *
+ * Removes the camera @cam from the list @list
+ */
 void entangle_camera_list_remove(EntangleCameraList *list,
                                  EntangleCamera *cam)
 {
@@ -375,6 +504,16 @@ void entangle_camera_list_remove(EntangleCameraList *list,
     g_object_unref(cam);
 }
 
+
+/**
+ * entangle_camera_list_get:
+ * @list: (transfer none): the camera list
+ * @entry: (transfer none): the index of the camera to get
+ *
+ * Get the camera at position @entry in the list
+ *
+ * Returns: (transfer none): the camera at position @entry
+ */
 EntangleCamera *entangle_camera_list_get(EntangleCameraList *list,
                                          int entry)
 {
@@ -391,9 +530,11 @@ EntangleCamera *entangle_camera_list_get(EntangleCameraList *list,
 
 /**
  * entangle_camera_list_get_cameras:
- * @list: the camera list
+ * @list: (transfer none): the camera list
  *
- * Returns: (transfer container): a list of #EntangleCamera objects
+ * Get the full list of cameras
+ *
+ * Returns: (transfer container)(element-type EntangleCamera): a list of #EntangleCamera objects
  */
 GList *entangle_camera_list_get_cameras(EntangleCameraList *list)
 {
@@ -407,6 +548,15 @@ GList *entangle_camera_list_get_cameras(EntangleCameraList *list)
 }
 
 
+/**
+ * entangle_camera_list_find:
+ * @list: (transfer none): the camera list
+ * @port: (transfer none): the hardware port address
+ *
+ * Get the camera connected to hardware address @port
+ *
+ * Returns: (transfer none): the camera connected to @port, or NULL
+ */
 EntangleCamera *entangle_camera_list_find(EntangleCameraList *list,
                                           const char *port)
 {
@@ -426,46 +576,6 @@ EntangleCamera *entangle_camera_list_find(EntangleCameraList *list,
 }
 
 
-static const gchar *entangle_camera_list_get_status(CameraDriverStatus status)
-{
-    switch (status) {
-    case GP_DRIVER_STATUS_PRODUCTION:
-        return "Production";
-    case GP_DRIVER_STATUS_TESTING:
-        return "Testing";
-    case GP_DRIVER_STATUS_EXPERIMENTAL:
-        return "Experimental";
-    case GP_DRIVER_STATUS_DEPRECATED:
-        return "Deprecated";
-    default:
-        return "Unknown";
-    }
-}
-
-
-gchar **entangle_camera_list_get_supported(EntangleCameraList *list)
-{
-    EntangleCameraListPrivate *priv = list->priv;
-    gchar **ret = NULL;
-    int cnt;
-    gsize i;
-
-    cnt = gp_abilities_list_count(priv->caps);
-
-    ret = g_new0(gchar *, cnt + 1);
-
-    for (i = 0; i < cnt; i++) {
-        CameraAbilities ab;
-        gp_abilities_list_get_abilities(priv->caps, i, &ab);
-
-        ret[i] = g_strdup_printf("%s (%s)",
-                                 ab.model,
-                                 entangle_camera_list_get_status(ab.status));
-    }
-    ret[cnt] = NULL;
-    return ret;
-}
-
 /*
  * Local variables:
  *  c-indent-level: 4
