@@ -184,11 +184,20 @@ gboolean entangle_camera_autofocus_finish(EntangleCamera *cam,
                                           GAsyncResult *result,
                                           GError **error);
 
+typedef enum {
+    ENTANGLE_CAMERA_MANUAL_FOCUS_STEP_IN_COARSE,
+    ENTANGLE_CAMERA_MANUAL_FOCUS_STEP_IN_MEDIUM,
+    ENTANGLE_CAMERA_MANUAL_FOCUS_STEP_IN_FINE,
+    ENTANGLE_CAMERA_MANUAL_FOCUS_STEP_OUT_COARSE,
+    ENTANGLE_CAMERA_MANUAL_FOCUS_STEP_OUT_MEDIUM,
+    ENTANGLE_CAMERA_MANUAL_FOCUS_STEP_OUT_FINE,
+} EntangleCameraManualFocusStep;
+
 gboolean entangle_camera_manualfocus(EntangleCamera *cam,
-                                     gshort delta,
+                                     EntangleCameraManualFocusStep step,
                                      GError **error);
 void entangle_camera_manualfocus_async(EntangleCamera *cam,
-                                       gshort delta,
+                                       EntangleCameraManualFocusStep step,
                                        GCancellable *cancellable,
                                        GAsyncReadyCallback callback,
                                        gpointer user_data);
@@ -196,6 +205,36 @@ gboolean entangle_camera_manualfocus_finish(EntangleCamera *cam,
                                             GAsyncResult *result,
                                             GError **error);
 
+gboolean entangle_camera_set_clock(EntangleCamera *cam,
+                                   gint64 epochsecs,
+                                   GError **error);
+void entangle_camera_set_clock_async(EntangleCamera *cam,
+                                     gint64 epochsecs,
+                                     GCancellable *cancellable,
+                                     GAsyncReadyCallback callback,
+                                     gpointer user_data);
+gboolean entangle_camera_set_clock_finish(EntangleCamera *cam,
+                                          GAsyncResult *result,
+                                          GError **error);
+
+
+typedef enum {
+    ENTANGLE_CAMERA_CAPTURE_TARGET_RAM,
+    ENTANGLE_CAMERA_CAPTURE_TARGET_CARD,
+} EntangleCameraCaptureTarget;
+
+gboolean entangle_camera_set_capture_target(EntangleCamera *cam,
+                                            EntangleCameraCaptureTarget target,
+                                            GError **error);
+void entangle_camera_set_capture_target_async(EntangleCamera *cam,
+                                              EntangleCameraCaptureTarget target,
+                                              GCancellable *cancellable,
+                                              GAsyncReadyCallback callback,
+                                              gpointer user_data);
+gboolean entangle_camera_set_capture_target_finish(EntangleCamera *cam,
+                                                   GAsyncResult *result,
+                                                   GError **error);
+
 
 gboolean entangle_camera_get_has_capture(EntangleCamera *cam);
 gboolean entangle_camera_get_has_preview(EntangleCamera *cam);
