@@ -21,6 +21,7 @@
 #include <config.h>
 
 #include <stdio.h>
+#include <string.h>
 
 #include "entangle-debug.h"
 #include "entangle-control-text.h"
@@ -65,13 +66,37 @@ static void entangle_control_set_property(GObject *object,
 {
     EntangleControlText *picker = ENTANGLE_CONTROL_TEXT(object);
     EntangleControlTextPrivate *priv = picker->priv;
+    gchar *newvalue;
 
     switch (prop_id)
         {
         case PROP_VALUE:
-            g_free(priv->value);
-            priv->value = g_value_dup_string(value);
-            entangle_control_set_dirty(ENTANGLE_CONTROL(object), TRUE);
+            newvalue = g_value_dup_string(value);
+            /* Hack, at least one Nikon D5100 appends 25 zeros
+             * on the end of the serial number, so we strip them
+             * here.
+             */
+            if (g_str_equal(entangle_control_get_path(ENTANGLE_CONTROL(object)),
+                            "/main/status/serialnumber")) {
+                size_t len = strlen(newvalue);
+                gboolean match = TRUE;
+                for (size_t i = 0; i < 25; i++) {
+                    if (newvalue[len-(1+i)] != '0')
+                        match = FALSE;
+                }
+                if (match)
+                    newvalue[len-25] = '\0';
+            }
+            if ((newvalue && !priv->value) ||
+                (!newvalue && priv->value) ||
+                (newvalue && priv->value &&
+                 !g_str_equal(newvalue, priv->value))) {
+                g_free(priv->value);
+                priv->value = newvalue;
+                entangle_control_set_dirty(ENTANGLE_CONTROL(object), TRUE);
+            } else {
+                g_free(newvalue);
+            }
             break;
 
         default:
