@@ -70,11 +70,13 @@ void entangle_preferences_interface_set_histogram_linear(EntanglePreferences *pr
 char *entangle_preferences_capture_get_last_session(EntanglePreferences *prefs);
 void entangle_preferences_capture_set_last_session(EntanglePreferences *prefs, const gchar *dir);
 char *entangle_preferences_capture_get_filename_pattern(EntanglePreferences *prefs);
-void entangle_preferences_capture_set_filename_pattern(EntanglePreferences *prefs, const gchar *dir);
+void entangle_preferences_capture_set_filename_pattern(EntanglePreferences *prefs, const gchar *pattern);
 gboolean entangle_preferences_capture_get_continuous_preview(EntanglePreferences *prefs);
 void entangle_preferences_capture_set_continuous_preview(EntanglePreferences *prefs, gboolean enabled);
 gboolean entangle_preferences_capture_get_delete_file(EntanglePreferences *prefs);
 void entangle_preferences_capture_set_delete_file(EntanglePreferences *prefs, gboolean enabled);
+gboolean entangle_preferences_capture_get_sync_clock(EntanglePreferences *prefs);
+void entangle_preferences_capture_set_sync_clock(EntanglePreferences *prefs, gboolean enabled);
 
 gboolean entangle_preferences_cms_get_enabled(EntanglePreferences *prefs);
 void entangle_preferences_cms_set_enabled(EntanglePreferences *prefs, gboolean enabled);
@@ -104,6 +106,10 @@ gboolean entangle_preferences_img_get_onion_skin(EntanglePreferences *prefs);
 void entangle_preferences_img_set_onion_skin(EntanglePreferences *prefs, gboolean enabled);
 gint entangle_preferences_img_get_onion_layers(EntanglePreferences *prefs);
 void entangle_preferences_img_set_onion_layers(EntanglePreferences *prefs, gint layers);
+gchar *entangle_preferences_img_get_background(EntanglePreferences *prefs);
+void entangle_preferences_img_set_background(EntanglePreferences *prefs, const gchar *bkg);
+gchar *entangle_preferences_img_get_highlight(EntanglePreferences *prefs);
+void entangle_preferences_img_set_highlight(EntanglePreferences *prefs, const gchar *bkg);
 
 G_END_DECLS
 
