@@ -86,7 +86,7 @@ int main(int argc, char **argv)
     entangle_debug_setup(debug_app, debug_gphoto);
 
     theme = gtk_icon_theme_get_default();
-    gtk_icon_theme_prepend_search_path(theme, PKGDATADIR "/icons");
+    gtk_icon_theme_prepend_search_path(theme, DATADIR "/icons");
 
     app = entangle_application_new();
 
