@@ -111,12 +111,14 @@ static void entangle_camera_support_finalize(GObject *object)
 
 static void do_entangle_camera_support_set_builder(EntangleWindow *window,
                                                    GtkBuilder *builder);
+static GtkBuilder *do_entangle_camera_support_get_builder(EntangleWindow *window);
 
 static void entangle_camera_support_window_interface_init(gpointer g_iface,
                                                           gpointer iface_data G_GNUC_UNUSED)
 {
     EntangleWindowInterface *iface = g_iface;
     iface->set_builder = do_entangle_camera_support_set_builder;
+    iface->get_builder = do_entangle_camera_support_get_builder;
 }
 
 
@@ -185,6 +187,15 @@ static void do_entangle_camera_support_set_builder(EntangleWindow *win,
 }
 
 
+static GtkBuilder *do_entangle_camera_support_get_builder(EntangleWindow *window)
+{
+    EntangleCameraSupport *support = ENTANGLE_CAMERA_SUPPORT(window);
+    EntangleCameraSupportPrivate *priv = support->priv;
+
+    return priv->builder;
+}
+
+
 static void entangle_camera_support_init(EntangleCameraSupport *support)
 {
     support->priv = ENTANGLE_CAMERA_SUPPORT_GET_PRIVATE(support);
@@ -199,27 +210,66 @@ static void do_support_refresh(EntangleCameraSupport *support)
     GtkWidget *text = GTK_WIDGET(gtk_builder_get_object(priv->builder, "info-text"));
 
     if (priv->cameraList) {
-        gchar **cameras = entangle_camera_list_get_supported(priv->cameraList);
-        gchar *tmp = g_strjoinv("\n", cameras);
-        gtk_label_set_text(GTK_LABEL(text), tmp);
-        g_free(tmp);
+        GList *cameras, *tmp;
+        GString *str = g_string_new("");
+        cameras = entangle_camera_list_get_cameras(priv->cameraList);
+        tmp = cameras = g_list_reverse(cameras);
+        while (tmp) {
+            EntangleCamera *cam = tmp->data;
+            gboolean cap = entangle_camera_get_has_capture(cam);
+            gboolean pre = entangle_camera_get_has_preview(cam);
+            gboolean set = entangle_camera_get_has_settings(cam);
+            if (cap || pre) {
+                gboolean done = FALSE;
+                g_string_append(str, entangle_camera_get_model(cam));
+                g_string_append(str, " (");
+                if (cap) {
+                    g_string_append(str, _("capture"));
+                    done = TRUE;
+                }
+                if (pre) {
+                    if (done)
+                        g_string_append(str, ", ");
+                    g_string_append(str, _("preview"));
+                    done = TRUE;
+                }
+                if (set) {
+                    if (done)
+                        g_string_append(str, ", ");
+                    g_string_append(str, _("settings"));
+                }
+                g_string_append(str, ")");
+                g_string_append(str, "\n");
+            }
+            tmp = tmp->next;
+        }
+        g_list_free(cameras);
+        gtk_label_set_text(GTK_LABEL(text), str->str);
+        g_string_free(str, TRUE);
     } else {
         gtk_label_set_text(GTK_LABEL(text), "");
     }
 }
 
 
+/**
+ * entangle_camera_support_set_camera_list:
+ * @support: the camera support widget
+ * @list: (transfer none)(allow-none): the list of cameras
+ *
+ * Set the camera list for the widget
+ */
 void entangle_camera_support_set_camera_list(EntangleCameraSupport *support,
-                                             EntangleCameraList *cameraList)
+                                             EntangleCameraList *list)
 {
     g_return_if_fail(ENTANGLE_IS_CAMERA_SUPPORT(support));
-    g_return_if_fail(ENTANGLE_IS_CAMERA_LIST(cameraList));
+    g_return_if_fail(ENTANGLE_IS_CAMERA_LIST(list));
 
     EntangleCameraSupportPrivate *priv = support->priv;
 
     if (priv->cameraList)
         g_object_unref(priv->cameraList);
-    priv->cameraList = cameraList;
+    priv->cameraList = list;
     if (priv->cameraList)
         g_object_ref(priv->cameraList);
 
@@ -227,6 +277,14 @@ void entangle_camera_support_set_camera_list(EntangleCameraSupport *support,
 }
 
 
+/**
+ * entangle_camera_support_get_camera_list:
+ * @support: the camera support widget
+ *
+ * Get the camera list
+ *
+ * Returns: (transfer none): the camera list or NULL
+ */
 EntangleCameraList *entangle_camera_support_get_camera_list(EntangleCameraSupport *support)
 {
     g_return_val_if_fail(ENTANGLE_IS_CAMERA_SUPPORT(support), NULL);
