@@ -41,9 +41,10 @@ struct _EntangleControlPanelPrivate {
     EntangleCamera *camera;
 
     gboolean hasControls;
+    gboolean inUpdate;
 };
 
-G_DEFINE_TYPE(EntangleControlPanel, entangle_control_panel, GTK_TYPE_VBOX);
+G_DEFINE_TYPE(EntangleControlPanel, entangle_control_panel, GTK_TYPE_BOX);
 
 enum {
     PROP_O,
@@ -95,16 +96,23 @@ static void do_update_control_finish(GObject *src,
 static gboolean do_refresh_control_entry_idle(gpointer data)
 {
     GtkWidget *widget = GTK_WIDGET(data);
+    EntangleControlPanel *panel = g_object_get_data(G_OBJECT(widget), "panel");
     GObject *control = g_object_get_data(G_OBJECT(widget), "control");
     gchar *text;
 
+    panel->priv->inUpdate = TRUE;
     g_object_get(control, "value", &text, NULL);
+    ENTANGLE_DEBUG("Notified control entry '%s' ('%s') with '%s'",
+                   entangle_control_get_path(ENTANGLE_CONTROL(control)),
+                   entangle_control_get_label(ENTANGLE_CONTROL(control)),
+                   text);
+
     if (GTK_IS_LABEL(widget))
         gtk_label_set_text(GTK_LABEL(widget), text);
     else
         gtk_entry_set_text(GTK_ENTRY(widget), text);
     g_free(text);
-
+    panel->priv->inUpdate = FALSE;
     return FALSE;
 }
 
@@ -126,9 +134,15 @@ static void do_update_control_entry(GtkWidget *widget,
     EntangleControlPanelPrivate *priv = panel->priv;
     const char *text;
 
+    if (panel->priv->inUpdate)
+        return;
+
     text = gtk_entry_get_text(GTK_ENTRY(widget));
 
-    ENTANGLE_DEBUG("entry [%s]", text);
+    ENTANGLE_DEBUG("Updated control entry '%s' ('%s') with '%s'",
+                   entangle_control_get_path(ENTANGLE_CONTROL(control)),
+                   entangle_control_get_label(ENTANGLE_CONTROL(control)),
+                   text);
     g_object_set(control, "value", text, NULL);
 
     entangle_camera_save_controls_async(priv->camera,
@@ -141,10 +155,17 @@ static void do_update_control_entry(GtkWidget *widget,
 static gboolean do_refresh_control_range_idle(gpointer data)
 {
     GtkWidget *widget = GTK_WIDGET(data);
+    EntangleControlPanel *panel = g_object_get_data(G_OBJECT(widget), "panel");
     GObject *control = g_object_get_data(G_OBJECT(widget), "control");
     gfloat val;
 
+    panel->priv->inUpdate = TRUE;
     g_object_get(control, "value", &val, NULL);
+    ENTANGLE_DEBUG("Notified control range '%s' ('%s') with '%lf'",
+                   entangle_control_get_path(ENTANGLE_CONTROL(control)),
+                   entangle_control_get_label(ENTANGLE_CONTROL(control)),
+                   val);
+
     if (GTK_IS_LABEL(widget)) {
         gchar *text = g_strdup_printf("%0.02f", val);
         gtk_label_set_text(GTK_LABEL(widget), text);
@@ -152,7 +173,7 @@ static gboolean do_refresh_control_range_idle(gpointer data)
     } else {
         gtk_range_set_value(GTK_RANGE(widget), val);
     }
-
+    panel->priv->inUpdate = FALSE;
     return FALSE;
 }
 
@@ -176,7 +197,13 @@ static void do_update_control_range(GtkRange *widget G_GNUC_UNUSED,
     EntangleControlPanel *panel = ENTANGLE_CONTROL_PANEL(data);
     EntangleControlPanelPrivate *priv = panel->priv;
 
-    ENTANGLE_DEBUG("range [%lf]", value);
+    if (panel->priv->inUpdate)
+        return;
+
+    ENTANGLE_DEBUG("Updated control range '%s' ('%s') with '%lf'",
+                   entangle_control_get_path(ENTANGLE_CONTROL(control)),
+                   entangle_control_get_label(ENTANGLE_CONTROL(control)),
+                   value);
     g_object_set(control, "value", (float)value, NULL);
 
     entangle_camera_save_controls_async(priv->camera,
@@ -189,22 +216,36 @@ static void do_update_control_range(GtkRange *widget G_GNUC_UNUSED,
 static gboolean do_refresh_control_combo_idle(gpointer data)
 {
     GtkWidget *widget = GTK_WIDGET(data);
+    EntangleControlPanel *panel = g_object_get_data(G_OBJECT(widget), "panel");
     GObject *control = g_object_get_data(G_OBJECT(widget), "control");
     gchar *text;
 
+    panel->priv->inUpdate = TRUE;
     g_object_get(control, "value", &text, NULL);
+    ENTANGLE_DEBUG("Notified control combo '%s' ('%s') with '%s'",
+                   entangle_control_get_path(ENTANGLE_CONTROL(control)),
+                   entangle_control_get_label(ENTANGLE_CONTROL(control)),
+                   text);
 
     if (GTK_IS_LABEL(widget)) {
         gtk_label_set_text(GTK_LABEL(widget), text);
     } else {
+        GtkListStore *store = GTK_LIST_STORE(gtk_combo_box_get_model(GTK_COMBO_BOX(widget)));
         int active = 0;
+        gtk_list_store_clear(store);
         for (int n = 0; n < entangle_control_choice_entry_count(ENTANGLE_CONTROL_CHOICE(control)); n++) {
+            GtkTreeIter iter;
             if (g_strcmp0(text, entangle_control_choice_entry_get(ENTANGLE_CONTROL_CHOICE(control), n)) == 0)
                 active = n;
+            gtk_list_store_append(store, &iter);
+            gtk_list_store_set(store, &iter, 0,
+                               entangle_control_choice_entry_get(ENTANGLE_CONTROL_CHOICE(control), n),
+                               -1);
         }
         gtk_combo_box_set_active(GTK_COMBO_BOX(widget), active);
     }
     g_free(text);
+    panel->priv->inUpdate = FALSE;
 
     return FALSE;
 }
@@ -230,10 +271,16 @@ static void do_update_control_combo(GtkComboBox *widget,
     char *text = NULL;
     GtkTreeModel *model = gtk_combo_box_get_model(widget);
 
+    if (panel->priv->inUpdate)
+        return;
+
     if (gtk_combo_box_get_active_iter(widget, &iter))
         gtk_tree_model_get(model, &iter, 0, &text, -1);
 
-    ENTANGLE_DEBUG("combo [%s]", text);
+    ENTANGLE_DEBUG("Updated control combo '%s' ('%s') with '%s'",
+                   entangle_control_get_path(ENTANGLE_CONTROL(control)),
+                   entangle_control_get_label(ENTANGLE_CONTROL(control)),
+                   text);
     g_object_set(control, "value", text, NULL);
 
     g_free(text);
@@ -248,16 +295,23 @@ static void do_update_control_combo(GtkComboBox *widget,
 static gboolean do_refresh_control_toggle_idle(gpointer data)
 {
     GtkWidget *widget = GTK_WIDGET(data);
+    EntangleControlPanel *panel = g_object_get_data(G_OBJECT(widget), "panel");
     GObject *control = g_object_get_data(G_OBJECT(widget), "control");
     gboolean state;
 
+    panel->priv->inUpdate = TRUE;
     g_object_get(control, "value", &state, NULL);
+    ENTANGLE_DEBUG("Notified control toggle '%s' ('%s') with '%d'",
+                   entangle_control_get_path(ENTANGLE_CONTROL(control)),
+                   entangle_control_get_label(ENTANGLE_CONTROL(control)),
+                   state);
+
     if (GTK_IS_LABEL(widget))
         gtk_label_set_text(GTK_LABEL(widget), state ? _("On") : _("Off"));
     else
         gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(widget),
                                      state);
-
+    panel->priv->inUpdate = FALSE;
     return FALSE;
 }
 
@@ -280,8 +334,14 @@ static void do_update_control_toggle(GtkToggleButton *widget,
     EntangleControlPanelPrivate *priv = panel->priv;
     gboolean active;
 
+    if (panel->priv->inUpdate)
+        return;
+
     active = gtk_toggle_button_get_active(widget);
-    ENTANGLE_DEBUG("toggle [%d]", active);
+    ENTANGLE_DEBUG("Updated control toggle '%s' ('%s') with '%d'",
+                   entangle_control_get_path(ENTANGLE_CONTROL(control)),
+                   entangle_control_get_label(ENTANGLE_CONTROL(control)),
+                   active);
     g_object_set(control, "value", active, NULL);
 
     entangle_camera_save_controls_async(priv->camera,
@@ -312,7 +372,7 @@ static void do_update_control_readonly(GObject *object G_GNUC_UNUSED,
 
 
 static void do_setup_control_group(EntangleControlPanel *panel,
-                                   GtkVBox *box,
+                                   GtkBox *box,
                                    EntangleControlGroup *grp)
 {
     g_return_if_fail(ENTANGLE_IS_CONTROL_PANEL(panel));
@@ -400,6 +460,7 @@ static void do_setup_control_group(EntangleControlPanel *panel,
                 gtk_widget_set_sensitive(value, FALSE);
             gtk_combo_box_set_active(GTK_COMBO_BOX(value), active);
 
+            g_object_set_data(G_OBJECT(value), "panel", panel);
             g_object_set_data(G_OBJECT(value), "control", control);
             g_signal_connect(value, "changed",
                              G_CALLBACK(do_update_control_combo), panel);
@@ -451,6 +512,7 @@ static void do_setup_control_group(EntangleControlPanel *panel,
             gtk_range_set_value(GTK_RANGE(value), offset);
             if (entangle_control_get_readonly(control) || forceReadonly)
                 gtk_widget_set_sensitive(value, FALSE);
+            g_object_set_data(G_OBJECT(value), "panel", panel);
             g_object_set_data(G_OBJECT(value), "control", control);
             g_signal_connect(value, "change-value",
                              G_CALLBACK(do_update_control_range), panel);
@@ -475,6 +537,7 @@ static void do_setup_control_group(EntangleControlPanel *panel,
             gtk_entry_set_text(GTK_ENTRY(value), text);
             if (entangle_control_get_readonly(control))
                 gtk_widget_set_sensitive(value, FALSE);
+            g_object_set_data(G_OBJECT(value), "panel", panel);
             g_object_set_data(G_OBJECT(value), "control", control);
             g_signal_connect(value, "focus-out-event",
                              G_CALLBACK(do_update_control_entry), panel);
@@ -492,6 +555,7 @@ static void do_setup_control_group(EntangleControlPanel *panel,
             gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(value), active);
             if (entangle_control_get_readonly(control))
                 gtk_widget_set_sensitive(value, FALSE);
+            g_object_set_data(G_OBJECT(value), "panel", panel);
             g_object_set_data(G_OBJECT(value), "control", control);
             g_signal_connect(value, "toggled",
                              G_CALLBACK(do_update_control_toggle), panel);
@@ -505,7 +569,7 @@ static void do_setup_control_group(EntangleControlPanel *panel,
 }
 
 static void do_setup_control_group_ro(EntangleControlPanel *panel,
-                                      GtkVBox *box,
+                                      GtkBox *box,
                                       EntangleControlGroup *grp)
 {
     g_return_if_fail(ENTANGLE_IS_CONTROL_PANEL(panel));
@@ -543,6 +607,7 @@ static void do_setup_control_group_ro(EntangleControlPanel *panel,
 
             g_object_get(control, "value", &text, NULL);
             value = gtk_label_new(text);
+            g_object_set_data(G_OBJECT(value), "panel", panel);
             g_object_set_data(G_OBJECT(value), "control", control);
             g_signal_connect(control, "notify::value",
                              G_CALLBACK(do_refresh_control_combo), value);
@@ -554,6 +619,7 @@ static void do_setup_control_group_ro(EntangleControlPanel *panel,
             text = g_strdup_printf("%d", date);
             value = gtk_label_new(text);
             g_free(text);
+            g_object_set_data(G_OBJECT(value), "panel", panel);
             g_object_set_data(G_OBJECT(value), "control", control);
         } else if (ENTANGLE_IS_CONTROL_RANGE(control)) {
             float offset;
@@ -563,6 +629,7 @@ static void do_setup_control_group_ro(EntangleControlPanel *panel,
             text = g_strdup_printf("%0.02f", offset);
             value = gtk_label_new(text);
             g_free(text);
+            g_object_set_data(G_OBJECT(value), "panel", panel);
             g_object_set_data(G_OBJECT(value), "control", control);
             g_signal_connect(control, "notify::value",
                              G_CALLBACK(do_refresh_control_range), value);
@@ -571,6 +638,7 @@ static void do_setup_control_group_ro(EntangleControlPanel *panel,
 
             g_object_get(control, "value", &text, NULL);
             value = gtk_label_new(text);
+            g_object_set_data(G_OBJECT(value), "panel", panel);
             g_object_set_data(G_OBJECT(value), "control", control);
             g_signal_connect(control, "notify::value",
                              G_CALLBACK(do_refresh_control_entry), value);
@@ -582,6 +650,7 @@ static void do_setup_control_group_ro(EntangleControlPanel *panel,
             text = g_strdup_printf("%s", active ? "Yes" : "No");
             value = gtk_label_new(text);
             g_free(text);
+            g_object_set_data(G_OBJECT(value), "panel", panel);
             g_object_set_data(G_OBJECT(value), "control", control);
             g_signal_connect(control, "notify::value",
                              G_CALLBACK(do_refresh_control_toggle), value);
@@ -640,9 +709,9 @@ static void do_setup_camera(EntangleControlPanel *panel)
         grp = entangle_control_group_get(ENTANGLE_CONTROL_GROUP(root), i);
         if (g_str_equal(entangle_control_get_path(ENTANGLE_CONTROL(grp)),
                         "/main/status"))
-            do_setup_control_group_ro(panel, GTK_VBOX(panel), ENTANGLE_CONTROL_GROUP(grp));
+            do_setup_control_group_ro(panel, GTK_BOX(panel), ENTANGLE_CONTROL_GROUP(grp));
         else
-            do_setup_control_group(panel, GTK_VBOX(panel), ENTANGLE_CONTROL_GROUP(grp));
+            do_setup_control_group(panel, GTK_BOX(panel), ENTANGLE_CONTROL_GROUP(grp));
     }
 
     gtk_widget_show_all(GTK_WIDGET(panel));
@@ -751,28 +820,46 @@ static void entangle_control_panel_init(EntangleControlPanel *panel)
     panel->priv = ENTANGLE_CONTROL_PANEL_GET_PRIVATE(panel);
 
     gtk_container_set_border_width(GTK_CONTAINER(panel), 0);
+    gtk_orientable_set_orientation(GTK_ORIENTABLE(panel),
+                                   GTK_ORIENTATION_VERTICAL);
 
     do_setup_camera(panel);
 }
 
 
+
+/**
+ * entangle_control_panel_set_camera:
+ * @panel: the control widget
+ * @camera: (transfer none)(allow-none): the camera to display controls for, or NULL
+ *
+ * Set the camera to display controls for
+ */
 void entangle_control_panel_set_camera(EntangleControlPanel *panel,
-                                       EntangleCamera *cam)
+                                       EntangleCamera *camera)
 {
     g_return_if_fail(ENTANGLE_IS_CONTROL_PANEL(panel));
-    g_return_if_fail(!cam || ENTANGLE_IS_CAMERA(cam));
+    g_return_if_fail(!camera || ENTANGLE_IS_CAMERA(camera));
 
     EntangleControlPanelPrivate *priv = panel->priv;
 
     if (priv->camera)
         g_object_unref(priv->camera);
-    priv->camera = cam;
+    priv->camera = camera;
     if (priv->camera)
         g_object_ref(priv->camera);
     do_setup_camera(panel);
 }
 
 
+/**
+ * entangle_control_panel_get_camera:
+ * @panel: the control widget
+ *
+ * Get the camera whose controls are displayed
+ *
+ * Returns: (transfer none): the camera or NULL
+ */
 EntangleCamera *entangle_control_panel_get_camera(EntangleControlPanel *panel)
 {
     g_return_val_if_fail(ENTANGLE_IS_CONTROL_PANEL(panel), NULL);
