@@ -76,6 +76,7 @@ void do_interface_histogram_linear_toggled(GtkToggleButton *src, EntanglePrefere
 void do_capture_filename_pattern_changed(GtkEntry *src, EntanglePreferencesDisplay *display);
 void do_capture_continuous_preview_toggled(GtkToggleButton *src, EntanglePreferencesDisplay *display);
 void do_capture_delete_file_toggled(GtkToggleButton *src, EntanglePreferencesDisplay *display);
+void do_capture_sync_clock_toggled(GtkToggleButton *src, EntanglePreferencesDisplay *display);
 
 void do_img_mask_enabled_toggled(GtkToggleButton *src, EntanglePreferencesDisplay *display);
 void do_img_aspect_ratio_changed(GtkComboBox *src, EntanglePreferencesDisplay *display);
@@ -85,6 +86,8 @@ void do_img_grid_lines_changed(GtkComboBox *src, EntanglePreferencesDisplay *dis
 void do_img_embedded_preview_toggled(GtkToggleButton *src, EntanglePreferencesDisplay *display);
 void do_img_onion_skin_toggled(GtkToggleButton *src, EntanglePreferencesDisplay *display);
 void do_img_onion_layers_changed(GtkSpinButton *src, EntanglePreferencesDisplay *display);
+void do_img_background_changed(GtkColorButton *src, EntanglePreferencesDisplay *display);
+void do_img_highlight_changed(GtkColorButton *src, EntanglePreferencesDisplay *display);
 
 static EntanglePreferences *entangle_preferences_display_get_preferences(EntanglePreferencesDisplay *preferences)
 {
@@ -222,6 +225,15 @@ static void entangle_preferences_display_notify(GObject *object,
         g_object_get(object, spec->name, &newvalue, NULL);
         oldvalue = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tmp));
 
+        if (newvalue != oldvalue)
+            gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp), newvalue);
+    } else if (strcmp(spec->name, "capture-sync-clock") == 0) {
+        gboolean newvalue;
+        gboolean oldvalue;
+
+        g_object_get(object, spec->name, &newvalue, NULL);
+        oldvalue = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(tmp));
+
         if (newvalue != oldvalue)
             gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp), newvalue);
     } else if (strcmp(spec->name, "img-mask-enabled") == 0) {
@@ -403,6 +415,9 @@ static void entangle_preferences_display_refresh(EntanglePreferencesDisplay *pre
     tmp = GTK_WIDGET(gtk_builder_get_object(priv->builder, "capture-delete-file"));
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp), entangle_preferences_capture_get_delete_file(prefs));
 
+    tmp = GTK_WIDGET(gtk_builder_get_object(priv->builder, "capture-sync-clock"));
+    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(tmp), entangle_preferences_capture_get_sync_clock(prefs));
+
     ratio = entangle_preferences_img_get_aspect_ratio(prefs);
     hasRatio = entangle_preferences_img_get_mask_enabled(prefs);
 
@@ -456,6 +471,20 @@ static void entangle_preferences_display_refresh(EntanglePreferencesDisplay *pre
 
     tmp = GTK_WIDGET(gtk_builder_get_object(priv->builder, "img-onion-layers-label"));
     gtk_widget_set_sensitive(tmp, hasOnion);
+
+    tmp = GTK_WIDGET(gtk_builder_get_object(priv->builder, "img-background"));
+    GdkRGBA gbg;
+    gchar *bg = entangle_preferences_img_get_background(prefs);
+    gdk_rgba_parse(&gbg, bg);
+    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(tmp), &gbg);
+    g_free(bg);
+
+    tmp = GTK_WIDGET(gtk_builder_get_object(priv->builder, "img-highlight"));
+    GdkRGBA ghl;
+    gchar *hl = entangle_preferences_img_get_highlight(prefs);
+    gdk_rgba_parse(&ghl, hl);
+    gtk_color_chooser_set_rgba(GTK_COLOR_CHOOSER(tmp), &ghl);
+    g_free(hl);
 }
 
 
@@ -477,12 +506,14 @@ static void entangle_preferences_display_finalize(GObject *object)
 
 static void do_entangle_preferences_display_set_builder(EntangleWindow *window,
                                                         GtkBuilder *builder);
+static GtkBuilder *do_entangle_preferences_display_get_builder(EntangleWindow *window);
 
 static void entangle_preferences_display_window_interface_init(gpointer g_iface,
                                                                gpointer iface_data G_GNUC_UNUSED)
 {
     EntangleWindowInterface *iface = g_iface;
     iface->set_builder = do_entangle_preferences_display_set_builder;
+    iface->get_builder = do_entangle_preferences_display_get_builder;
 }
 
 static void entangle_preferences_display_class_init(EntanglePreferencesDisplayClass *klass)
@@ -690,6 +721,17 @@ void do_capture_delete_file_toggled(GtkToggleButton *src, EntanglePreferencesDis
 }
 
 
+void do_capture_sync_clock_toggled(GtkToggleButton *src, EntanglePreferencesDisplay *preferences)
+{
+    g_return_if_fail(ENTANGLE_IS_PREFERENCES_DISPLAY(preferences));
+
+    EntanglePreferences *prefs = entangle_preferences_display_get_preferences(preferences);
+    gboolean enabled = gtk_toggle_button_get_active(src);
+
+    entangle_preferences_capture_set_sync_clock(prefs, enabled);
+}
+
+
 void do_img_mask_enabled_toggled(GtkToggleButton *src, EntanglePreferencesDisplay *preferences)
 {
     g_return_if_fail(ENTANGLE_IS_PREFERENCES_DISPLAY(preferences));
@@ -808,6 +850,32 @@ void do_img_onion_layers_changed(GtkSpinButton *src, EntanglePreferencesDisplay
                                               gtk_adjustment_get_value(adjust));
 }
 
+void do_img_background_changed(GtkColorButton *src, EntanglePreferencesDisplay *preferences)
+{
+    g_return_if_fail(ENTANGLE_IS_PREFERENCES_DISPLAY(preferences));
+
+    EntanglePreferences *prefs = entangle_preferences_display_get_preferences(preferences);
+
+    GdkRGBA gbg;
+    gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(src), &gbg);
+    gchar *bg = gdk_rgba_to_string(&gbg);
+    entangle_preferences_img_set_background(prefs, bg);
+    g_free(bg);
+}
+
+void do_img_highlight_changed(GtkColorButton *src, EntanglePreferencesDisplay *preferences)
+{
+    g_return_if_fail(ENTANGLE_IS_PREFERENCES_DISPLAY(preferences));
+
+    EntanglePreferences *prefs = entangle_preferences_display_get_preferences(preferences);
+
+    GdkRGBA ghl;
+    gtk_color_chooser_get_rgba(GTK_COLOR_CHOOSER(src), &ghl);
+    gchar *hl = gdk_rgba_to_string(&ghl);
+    entangle_preferences_img_set_highlight(prefs, hl);
+    g_free(hl);
+}
+
 
 static void do_entangle_preferences_display_set_builder(EntangleWindow *win,
                                                         GtkBuilder *builder)
@@ -817,7 +885,6 @@ static void do_entangle_preferences_display_set_builder(EntangleWindow *win,
     GtkWidget *notebook;
     GtkWidget *box;
     GtkWidget *image;
-    gboolean local = FALSE;
     GtkListStore *list;
     GtkWidget *tree;
     GtkTreeIter iter;
@@ -831,6 +898,7 @@ static void do_entangle_preferences_display_set_builder(EntangleWindow *win,
     GtkFileFilter *iccFilter;
     GtkComboBox *aspectRatio;
     GtkComboBox *gridLines;
+    GtkIconTheme *theme = gtk_icon_theme_get_default();
 
     priv->builder = g_object_ref(builder);
 
@@ -843,117 +911,66 @@ static void do_entangle_preferences_display_set_builder(EntangleWindow *win,
     //gtk_notebook_remove_page(GTK_NOTEBOOK(notebook), 2);
 
     box = GTK_WIDGET(gtk_builder_get_object(priv->builder, "interface-box"));
-    gtk_widget_set_state(box, GTK_STATE_SELECTED);
+    gtk_widget_set_state_flags(box, GTK_STATE_FLAG_SELECTED, TRUE);
     image = GTK_WIDGET(gtk_builder_get_object(priv->builder, "interface-image"));
-    if (local)
-        gtk_image_set_from_file(GTK_IMAGE(image), "./interface.png");
-    else
-        gtk_image_set_from_file(GTK_IMAGE(image), PKGDATADIR "/interface.png");
+    gtk_image_set_from_icon_name(GTK_IMAGE(image), "entangle-interface", GTK_ICON_SIZE_DIALOG);
 
     box = GTK_WIDGET(gtk_builder_get_object(priv->builder, "cms-box"));
-    gtk_widget_set_state(box, GTK_STATE_SELECTED);
+    gtk_widget_set_state_flags(box, GTK_STATE_FLAG_SELECTED, TRUE);
     image = GTK_WIDGET(gtk_builder_get_object(priv->builder, "cms-image"));
-    if (local)
-        gtk_image_set_from_file(GTK_IMAGE(image), "./color-management.png");
-    else
-        gtk_image_set_from_file(GTK_IMAGE(image), PKGDATADIR "/color-management.png");
+    gtk_image_set_from_icon_name(GTK_IMAGE(image), "entangle-color-management", GTK_ICON_SIZE_DIALOG);
 
     box = GTK_WIDGET(gtk_builder_get_object(priv->builder, "capture-box"));
-    gtk_widget_set_state(box, GTK_STATE_SELECTED);
+    gtk_widget_set_state_flags(box, GTK_STATE_FLAG_SELECTED, TRUE);
     image = GTK_WIDGET(gtk_builder_get_object(priv->builder, "capture-image"));
-    if (local)
-        gtk_image_set_from_file(GTK_IMAGE(image), "./capture.png");
-    else
-        gtk_image_set_from_file(GTK_IMAGE(image), PKGDATADIR "/capture.png");
+    gtk_image_set_from_icon_name(GTK_IMAGE(image), "entangle-capture", GTK_ICON_SIZE_DIALOG);
 
     box = GTK_WIDGET(gtk_builder_get_object(priv->builder, "plugins-box"));
-    gtk_widget_set_state(box, GTK_STATE_SELECTED);
+    gtk_widget_set_state_flags(box, GTK_STATE_FLAG_SELECTED, TRUE);
     image = GTK_WIDGET(gtk_builder_get_object(priv->builder, "plugins-image"));
-    if (local)
-        gtk_image_set_from_file(GTK_IMAGE(image), "./plugins.png");
-    else
-        gtk_image_set_from_file(GTK_IMAGE(image), PKGDATADIR "/plugins.png");
-
+    gtk_image_set_from_icon_name(GTK_IMAGE(image), "entangle-plugins", GTK_ICON_SIZE_DIALOG);
 
     box = GTK_WIDGET(gtk_builder_get_object(priv->builder, "img-box"));
-    gtk_widget_set_state(box, GTK_STATE_SELECTED);
+    gtk_widget_set_state_flags(box, GTK_STATE_FLAG_SELECTED, TRUE);
     image = GTK_WIDGET(gtk_builder_get_object(priv->builder, "img-image"));
-    if (local)
-        gtk_image_set_from_file(GTK_IMAGE(image), "./imageviewer.png");
-    else
-        gtk_image_set_from_file(GTK_IMAGE(image), PKGDATADIR "/imageviewer.png");
+    gtk_image_set_from_icon_name(GTK_IMAGE(image), "entangle-imageviewer", GTK_ICON_SIZE_DIALOG);
 
     list = gtk_list_store_new(3, G_TYPE_INT, G_TYPE_STRING, GDK_TYPE_PIXBUF, -1);
 
     gtk_list_store_append(list, &iter);
-    if (local)
-        gtk_list_store_set(list, &iter,
-                           0, 3,
-                           1, _("Interface"),
-                           2, gdk_pixbuf_new_from_file("./interface-22.png", NULL),
-                           -1);
-    else
-        gtk_list_store_set(list, &iter,
-                           0, 3,
-                           1, _("Interface"),
-                           2, gdk_pixbuf_new_from_file(PKGDATADIR "/interface-22.png", NULL),
-                           -1);
+    gtk_list_store_set(list, &iter,
+                       0, 3,
+                       1, _("Interface"),
+                       2, gtk_icon_theme_load_icon(theme, "entangle-interface", 22, 0, NULL),
+                       -1);
 
     gtk_list_store_append(list, &iter);
-    if (local)
-        gtk_list_store_set(list, &iter,
-                           0, 4,
-                           1, _("Image Viewer"),
-                           2, gdk_pixbuf_new_from_file("./imageviewer-22.png", NULL),
-                           -1);
-    else
-        gtk_list_store_set(list, &iter,
-                           0, 4,
-                           1, _("Image Viewer"),
-                           2, gdk_pixbuf_new_from_file(PKGDATADIR "/imageviewer-22.png", NULL),
-                           -1);
+    gtk_list_store_set(list, &iter,
+                       0, 4,
+                       1, _("Image Viewer"),
+                       2, gtk_icon_theme_load_icon(theme, "entangle-imageviewer", 22, 0, NULL),
+                       -1);
 
     gtk_list_store_append(list, &iter);
-    if (local)
-        gtk_list_store_set(list, &iter,
-                           0, 0,
-                           1, _("Capture"),
-                           2, gdk_pixbuf_new_from_file("./capture-22.png", NULL),
-                           -1);
-    else
-        gtk_list_store_set(list, &iter,
-                           0, 0,
-                           1, _("Capture"),
-                           2, gdk_pixbuf_new_from_file(PKGDATADIR "/capture-22.png", NULL),
-                           -1);
+    gtk_list_store_set(list, &iter,
+                       0, 0,
+                       1, _("Capture"),
+                       2, gtk_icon_theme_load_icon(theme, "entangle-capture", 22, 0, NULL),
+                       -1);
 
     gtk_list_store_append(list, &iter);
-    if (local)
-        gtk_list_store_set(list, &iter,
-                           0, 1,
-                           1, _("Color Management"),
-                           2, gdk_pixbuf_new_from_file("./color-management-22.png", NULL),
-                           -1);
-    else
-        gtk_list_store_set(list, &iter,
-                           0, 1,
-                           1, _("Color Management"),
-                           2, gdk_pixbuf_new_from_file(PKGDATADIR "/color-management-22.png", NULL),
-                           -1);
+    gtk_list_store_set(list, &iter,
+                       0, 1,
+                       1, _("Color Management"),
+                       2, gtk_icon_theme_load_icon(theme, "entangle-color-management", 22, 0, NULL),
+                       -1);
 
     gtk_list_store_append(list, &iter);
-    if (local)
-        gtk_list_store_set(list, &iter,
-                           0, 2,
-                           1, _("Plugins"),
-                           2, gdk_pixbuf_new_from_file("./plugins-22.png", NULL),
-                           -1);
-    else
-        gtk_list_store_set(list, &iter,
-                           0, 2,
-                           1, _("Plugins"),
-                           2, gdk_pixbuf_new_from_file(PKGDATADIR "/plugins-22.png", NULL),
-                           -1);
+    gtk_list_store_set(list, &iter,
+                       0, 2,
+                       1, _("Plugins"),
+                       2, gtk_icon_theme_load_icon(theme, "entangle-plugins", 22, 0, NULL),
+                       -1);
 
     cellText = gtk_cell_renderer_text_new();
     cellImage = gtk_cell_renderer_pixbuf_new();
@@ -1179,6 +1196,16 @@ static void do_entangle_preferences_display_set_builder(EntangleWindow *win,
     g_signal_connect(selection, "changed", G_CALLBACK(do_page_changed), preferences);
 }
 
+
+static GtkBuilder *do_entangle_preferences_display_get_builder(EntangleWindow *window)
+{
+    EntanglePreferencesDisplay *display = ENTANGLE_PREFERENCES_DISPLAY(window);
+    EntanglePreferencesDisplayPrivate *priv = display->priv;
+
+    return priv->builder;
+}
+
+
 static void entangle_preferences_display_init(EntanglePreferencesDisplay *preferences)
 {
     preferences->priv = ENTANGLE_PREFERENCES_DISPLAY_GET_PRIVATE(preferences);
